@@ -92,7 +92,7 @@ class HellaSwagTask(Enum):
     LONGBOARDING = "Longboarding"
     POLE_VAULT = "Pole vault"
     BUILDING_SANDCASTLES = "Building sandcastles"
-    PLATFORM_DIVING = "Plataform diving"
+    PLATFORM_DIVING = "Platform diving"
     PAINTING = "Painting"
     SPINNING = "Spinning"
     CARVING_JACK_O_LANTERNS = "Carving jack-o-lanterns"
@@ -186,7 +186,7 @@ class HellaSwagTask(Enum):
     PLAYING_SQUASH = "Playing squash"
     HOPSCOTCH = "Hopscotch"
     INSTALLING_CARPET = "Installing carpet"
-    POLISHING_FURNITURE = "Polishing forniture"
+    POLISHING_FURNITURE = "Polishing furniture"
     DECORATING_THE_CHRISTMAS_TREE = "Decorating the Christmas tree"
     PREPARING_SALAD = "Preparing salad"
     PREPARING_PASTA = "Preparing pasta"
