@@ -1,16 +1,74 @@
-from typing import List, Optional, Dict, Tuple
-from datasets import load_dataset
-import pandas as pd
+from typing import List, Optional, Dict
 
 from deepeval.dataset import Golden
-from deepeval.benchmarks.base_benchmark import DeepEvalBaseBenchmark
+from deepeval.benchmarks.base_benchmark import (
+    DeepEvalBaseBenchmark,
+    DeepEvalBaseBenchmarkResult,
+)
 from deepeval.models import DeepEvalBaseLLM
 from deepeval.benchmarks.human_eval.task import HumanEvalTask
 from deepeval.benchmarks.human_eval.template import HumanEvalTemplate
-from deepeval.scorer import Scorer
 from deepeval.telemetry import capture_benchmark_run
 
 
+def secure_exec(code_str, global_vars=None, local_vars=None):
+    """Securely execute code with restricted globals and locals."""
+    if global_vars is None:
+        global_vars = {}
+    if local_vars is None:
+        local_vars = {}
+
+    # Create a restricted globals dictionary with only safe built-ins
+    safe_globals = {
+        "__builtins__": {
+            "abs": abs,
+            "all": all,
+            "any": any,
+            "bin": bin,
+            "bool": bool,
+            "chr": chr,
+            "dict": dict,
+            "enumerate": enumerate,
+            "filter": filter,
+            "float": float,
+            "hex": hex,
+            "int": int,
+            "len": len,
+            "list": list,
+            "map": map,
+            "max": max,
+            "min": min,
+            "oct": oct,
+            "ord": ord,
+            "pow": pow,
+            "range": range,
+            "reversed": reversed,
+            "round": round,
+            "set": set,
+            "sorted": sorted,
+            "str": str,
+            "sum": sum,
+            "tuple": tuple,
+            "zip": zip,
+            "Exception": Exception,
+            "ValueError": ValueError,
+            "TypeError": TypeError,
+            "IndexError": IndexError,
+            "KeyError": KeyError,
+        }
+    }
+    safe_globals.update(global_vars)
+
+    try:
+        # Compile the code first to validate syntax
+        compiled_code = compile(code_str, "<string>", "exec")
+        # Execute with restricted environment
+        exec(compiled_code, safe_globals, local_vars)
+        return local_vars
+    except Exception as e:
+        raise e
+
+
 class HumanEval(DeepEvalBaseBenchmark):
     def __init__(
         self,
@@ -19,6 +77,9 @@ class HumanEval(DeepEvalBaseBenchmark):
         verbose_mode: bool = False,
         **kwargs,
     ):
+        from deepeval.scorer import Scorer
+        import pandas as pd
+
         super().__init__(**kwargs)
         self.tasks: List[HumanEvalTask] = (
             list(HumanEvalTask) if tasks is None else tasks
@@ -33,7 +94,11 @@ class HumanEval(DeepEvalBaseBenchmark):
         self.overall_score: Optional[float] = None
         self.verbose_mode: bool = (False,)
 
-    def evaluate(self, model: DeepEvalBaseLLM, k: int) -> Dict:
+    def evaluate(
+        self, model: DeepEvalBaseLLM, *args, k: int = 1, **kwargs
+    ) -> DeepEvalBaseBenchmarkResult:
+        import pandas as pd
+
         with capture_benchmark_run("HumanEval", len(self.tasks)):
             assert self.n >= k
             overall_correct_predictions = 0
@@ -95,7 +160,9 @@ class HumanEval(DeepEvalBaseBenchmark):
             )
             self.overall_score = overall_accuracy
 
-            return overall_accuracy
+            return DeepEvalBaseBenchmarkResult(
+                overall_accuracy=overall_accuracy
+            )
 
     def predict(
         self,
@@ -120,8 +187,8 @@ class HumanEval(DeepEvalBaseBenchmark):
             c = 0
             for function in functions:
                 try:
-                    exec(function)
-                    exec(golden.expected_output)
+                    secure_exec(function)
+                    secure_exec(golden.expected_output)
                     c += 1
                 except AssertionError as e:
                     pass
@@ -133,11 +200,13 @@ class HumanEval(DeepEvalBaseBenchmark):
         return {"prediction": functions, "score": score}
 
     def load_benchmark_dataset(self, task: HumanEvalTask) -> List[Golden]:
+        from datasets import load_dataset
+
         # Cache
         if self.dataset:
             dataset = self.dataset
         else:
-            dataset = load_dataset("openai_humaneval", trust_remote_code=True)
+            dataset = load_dataset("openai_humaneval")
             self.dataset = dataset
 
         # Filter tasks
