@@ -5,7 +5,7 @@ class MMLUTemplate:
 
     # Most of this template was taken from MMLU Github Repo
     # The output confinement is a novel addition, since the original code
-    # outputted log_probabilties for each answer choice
+    # outputted log_probabilities for each answer choice
 
     @staticmethod
     def generate_output(
@@ -20,14 +20,14 @@ class MMLUTemplate:
 
     @staticmethod
     def format_question(data: dict, include_answer: bool = True):
-        prompt = data["input"]
+        prompt = data["question"]
         choices = ["A", "B", "C", "D"]
         for j in range(len(choices)):
             choice = choices[j]
-            prompt += "\n{}. {}".format(choice, data[choice])
+            prompt += "\n{}. {}".format(choice, data["choices"][j])
         prompt += "\nAnswer:"
         if include_answer:
-            prompt += " {}\n\n".format(data["target"])
+            prompt += " {}\n\n".format(choices[data["answer"]])
         return prompt
 
     @staticmethod
