@@ -1,2 +1,7 @@
-from ..truthful_qa.truthful_qa import TruthfulQAMode
 from ..arc.arc import ARCMode
+from ..truthful_qa.truthful_qa import TruthfulQAMode
+
+__all__ = [
+    "ARCMode",
+    "TruthfulQAMode",
+]
