@@ -1,16 +1,15 @@
-from typing import List, Dict, Union, Optional
+from typing import Dict, Optional, Any
 from pydantic import BaseModel
 
 
 class Knowledge(BaseModel):
-    data: Dict[str, Union[str, List[str]]]
+    data: Dict[str, Any]
 
 
 class KnowledgeRetentionVerdict(BaseModel):
     verdict: str
-    index: Optional[int] = None
     reason: Optional[str] = None
 
 
-class Reason(BaseModel):
+class KnowledgeRetentionScoreReason(BaseModel):
     reason: str
