@@ -4,6 +4,7 @@ from .context import (
     update_retriever_span,
     update_llm_span,
 )
+from .trace_context import trace, LlmSpanContext
 from .types import BaseSpan, Trace
 from .tracing import observe, trace_manager
 from .offline_evals import evaluate_thread, evaluate_trace, evaluate_span
@@ -13,9 +14,11 @@ __all__ = [
     "update_current_trace",
     "update_retriever_span",
     "update_llm_span",
+    "LlmSpanContext",
     "BaseSpan",
     "Trace",
     "observe",
+    "trace",
     "trace_manager",
     "evaluate_thread",
     "evaluate_trace",
